@@ -25,9 +25,7 @@
 
 #include <kmime/kmime_message.h>
 
-namespace KMBox
-{
-
+namespace KMBox {
 class MBoxPrivate;
 
 /**
@@ -71,7 +69,7 @@ public:
      * @return the corresponding mbox entry for the message in the file or an invalid mbox entry
      *         if the message was not added.
      */
-    MBoxEntry appendMessage(const KMime::Message::Ptr &message);
+    Q_REQUIRED_RESULT MBoxEntry appendMessage(const KMime::Message::Ptr &message);
 
     /**
      * Retrieve the mbox entry objects for all emails from the file except the
@@ -80,12 +78,12 @@ public:
      * @param deletedEntries list of mbox entries that have been deleted and need not be retrieved
      * Note: One <em>must</em> call load() before calling this method.
      */
-    MBoxEntry::List entries(const MBoxEntry::List &deletedEntries = MBoxEntry::List()) const;
+    Q_REQUIRED_RESULT MBoxEntry::List entries(const MBoxEntry::List &deletedEntries = MBoxEntry::List()) const;
 
     /**
      * Returns the file name that was passed to the last call to load().
      */
-    QString fileName() const;
+    Q_REQUIRED_RESULT QString fileName() const;
 
     /**
      * Loads the raw mbox data from disk into the current MBox object. Messages
@@ -99,7 +97,7 @@ public:
      *
      * @see save( const QString & )
      */
-    bool load(const QString &fileName);
+    Q_REQUIRED_RESULT bool load(const QString &fileName);
 
     /**
      * Locks the mbox file using the configured lock method. This can be used
@@ -113,12 +111,12 @@ public:
      *
      * @see setLockType( LockType ), unlock()
      */
-    bool lock();
+    Q_REQUIRED_RESULT bool lock();
 
     /**
      * Returns whether or not the mbox currently is locked.
      */
-    bool locked() const;
+    Q_REQUIRED_RESULT bool locked() const;
 
     /**
      * Removes all messages for the given mbox entries from the current reference file
@@ -138,7 +136,7 @@ public:
      *         loaded, false otherwise. If the latter, the physical file has
      *         not changed.
      */
-    bool purge(const MBoxEntry::List &deletedEntries, QList<MBoxEntry::Pair> *movedEntries = Q_NULLPTR);
+    Q_REQUIRED_RESULT bool purge(const MBoxEntry::List &deletedEntries, QList<MBoxEntry::Pair> *movedEntries = nullptr);
 
     /**
      * Reads the entire message from the file for the given mbox @p entry. If the
@@ -165,7 +163,7 @@ public:
      *
      * @see lock(), unlock()
      */
-    QByteArray readMessageHeaders(const MBoxEntry &entry);
+    Q_REQUIRED_RESULT QByteArray readMessageHeaders(const MBoxEntry &entry);
 
     /**
      * Reads the entire message from the file for the given mbox @p entry. If the
@@ -178,7 +176,7 @@ public:
      *
      * @see lock(), unlock()
      */
-    QByteArray readRawMessage(const MBoxEntry &entry);
+    Q_REQUIRED_RESULT QByteArray readRawMessage(const MBoxEntry &entry);
 
     /**
      * Writes the mbox to disk. If the fileName is empty only appended messages
@@ -191,7 +189,7 @@ public:
      *
      * @see load( const QString & )
      */
-    bool save(const QString &fileName = QString());
+    Q_REQUIRED_RESULT bool save(const QString &fileName = QString());
 
     /**
      * Sets the locktype that should be used for locking the mbox file. If the
@@ -202,7 +200,7 @@ public:
      * to make sure that it doesn't leave a locked file for one of the lockfile
      * / mutt_dotlock methods.
      */
-    bool setLockType(LockType ltype);
+    Q_REQUIRED_RESULT bool setLockType(LockType ltype);
 
     /**
      * Sets the lockfile that should be used by the procmail or the KDE lock
@@ -229,7 +227,7 @@ public:
      *
      * @see lock()
      */
-    bool unlock();
+    Q_REQUIRED_RESULT bool unlock();
     /**
      * Set the access mode of the mbox file to read only.
      *
@@ -255,16 +253,15 @@ public:
      *
      * @since 4.14.5
      */
-    bool isReadOnly() const;
-
+    Q_REQUIRED_RESULT bool isReadOnly() const;
 
 private:
     //@cond PRIVATE
+    Q_DISABLE_COPY(MBox)
     friend class MBoxPrivate;
     MBoxPrivate *const d;
     //@endcond
 };
-
 }
 
 #endif // KMBOX_MBOX_H
